@@ -5,7 +5,7 @@ import hashlib
 import io
 import tempfile
 import uuid
-from typing import List, Optional
+from typing import Optional
 
 import falcon
 import orjson
@@ -54,16 +54,22 @@ from robotoff.off import (
 from robotoff.prediction.category import predict_category
 from robotoff.prediction.object_detection import ObjectDetectionModelRegistry
 from robotoff.prediction.ocr.dataclass import OCRParsingException
-from robotoff.prediction.types import PredictionType
 from robotoff.products import get_product_dataset_etag
 from robotoff.spellcheck import SPELLCHECKERS, Spellchecker
 from robotoff.taxonomy import is_prefixed_value, match_taxonomized_value
+from robotoff.types import PredictionType
 from robotoff.utils import get_image_from_url, get_logger, http_session
 from robotoff.utils.es import get_es_client
 from robotoff.utils.i18n import TranslationStore
 from robotoff.utils.text import get_tag
 from robotoff.utils.types import JSONType
-from robotoff.workers.client import send_ipc_event
+from robotoff.workers.queues import enqueue_in_job, enqueue_job, high_queue, low_queue
+from robotoff.workers.tasks import (
+    delete_product_insights_job,
+    download_product_dataset_job,
+    run_import_image_job,
+    update_insights_job,
+)
 
 logger = get_logger()
 
@@ -129,7 +135,7 @@ class InsightCollection:
         response: JSONType = {}
         count: int = req.get_param_as_int("count", min_value=1, default=25)
         page: int = req.get_param_as_int("page", min_value=1, default=1)
-        keep_types: Optional[List[str]] = req.get_param_as_list(
+        keep_types: Optional[list[str]] = req.get_param_as_list(
             "insight_types", required=False
         )
         barcode: Optional[str] = req.get_param("barcode")
@@ -258,6 +264,10 @@ class AnnotateInsightResource:
         data = req.get_param_as_json("data")
 
         auth = parse_auth(req)
+        if auth is not None and auth.get_username() == "null":
+            # Smoothie currently sends 'null' as username for anonymous voters
+            auth = None
+
         trusted_annotator = auth is not None
 
         device_id = device_id_from_request(req)
@@ -408,7 +418,7 @@ class CategoryPredictorResource:
     def on_post(self, req: falcon.Request, resp: falcon.Response):
         """Predict categories using neural categorizer and matching algorithm
         for a specific product."""
-        predictors: List[str] = req.media.get("predictors") or ["neural", "matcher"]
+        predictors: list[str] = req.media.get("predictors") or ["neural", "matcher"]
 
         if "barcode" in req.media:
             # Fetch product from DB
@@ -438,7 +448,11 @@ class CategoryPredictorResource:
 
 class UpdateDatasetResource:
     def on_post(self, req: falcon.Request, resp: falcon.Response):
-        send_ipc_event("download_dataset")
+        """Re-import the Product Opener product dump."""
+
+        enqueue_job(
+            download_product_dataset_job, queue=low_queue, job_kwargs={"timeout": "1h"}
+        )
 
         resp.media = {
             "status": "scheduled",
@@ -458,22 +472,21 @@ class ImageImporterResource:
         server_domain = req.get_param("server_domain", required=True)
 
         if server_domain != settings.OFF_SERVER_DOMAIN:
-            logger.info("Rejecting image import from {}".format(server_domain))
+            logger.info("Rejecting image import from %s", server_domain)
             resp.media = {
                 "status": "rejected",
             }
             return
 
-        send_ipc_event(
-            "import_image",
-            {
-                "barcode": barcode,
-                "image_url": image_url,
-                "ocr_url": ocr_url,
-                "server_domain": server_domain,
-            },
+        enqueue_job(
+            run_import_image_job,
+            high_queue,
+            job_kwargs={"result_ttl": 0},
+            barcode=barcode,
+            image_url=image_url,
+            ocr_url=ocr_url,
+            server_domain=server_domain,
         )
-
         resp.media = {
             "status": "scheduled",
         }
@@ -576,7 +589,7 @@ class ImagePredictionFetchResource:
 class ImagePredictorResource:
     def on_get(self, req: falcon.Request, resp: falcon.Response):
         image_url = req.get_param("image_url", required=True)
-        models: List[str] = req.get_param_as_list("models", required=True)
+        models: list[str] = req.get_param_as_list("models", required=True)
 
         available_models = ObjectDetectionModelRegistry.get_available_models()
 
@@ -631,7 +644,9 @@ def image_response(image: Image.Image, resp: falcon.Response) -> None:
 
 class ImageLogoResource:
     def on_get(self, req: falcon.Request, resp: falcon.Response):
-        logo_ids: List[str] = req.get_param_as_list("logo_ids", required=True)
+        logo_ids: list[str] = req.get_param_as_list(
+            "logo_ids", transform=int, required=True
+        )
         logos = []
         for logo in (
             LogoAnnotation.select()
@@ -804,6 +819,10 @@ class ImageLogoAnnotateResource:
             except LogoAnnotation.DoesNotExist:
                 raise falcon.HTTPNotFound(description=f"logo {logo_id} not found")
 
+            if logo.annotation_type is not None:
+                # Logo is already annotated, skip
+                continue
+
             if value is not None:
                 if type_ == "label" and not is_prefixed_value(value):
                     raise falcon.HTTPBadRequest(
@@ -893,19 +912,20 @@ class WebhookProductResource:
             )
 
         if action == "updated":
-            send_ipc_event(
-                "product_updated",
-                {
-                    "barcode": barcode,
-                    "server_domain": server_domain,
-                    # add some latency
-                    "task_delay": settings.UPDATED_PRODUCT_WAIT,
-                },
+            enqueue_in_job(
+                update_insights_job,
+                high_queue,
+                settings.UPDATED_PRODUCT_WAIT,
+                barcode=barcode,
+                server_domain=server_domain,
             )
-
         elif action == "deleted":
-            send_ipc_event(
-                "product_deleted", {"barcode": barcode, "server_domain": server_domain}
+            enqueue_job(
+                delete_product_insights_job,
+                high_queue,
+                job_kwargs={"result_ttl": 0},
+                barcode=barcode,
+                server_domain=server_domain,
             )
 
         resp.media = {
@@ -948,7 +968,7 @@ class ProductQuestionsResource:
             response["questions"] = []
             response["status"] = "no_questions"
         else:
-            questions: List[JSONType] = []
+            questions: list[JSONType] = []
 
             for insight in insights:
                 formatter_cls = QuestionFormatterFactory.get(insight.type)
@@ -979,7 +999,7 @@ def get_questions_resource_on_get(
     page: int = req.get_param_as_int("page", min_value=1, default=1)
     count: int = req.get_param_as_int("count", min_value=1, default=25)
     lang: str = req.get_param("lang", default="en")
-    keep_types: Optional[List[str]] = req.get_param_as_list(
+    keep_types: Optional[list[str]] = req.get_param_as_list(
         "insight_types", required=False
     )
     country: Optional[str] = req.get_param("country")
@@ -1036,7 +1056,7 @@ def get_questions_resource_on_get(
         response["questions"] = []
         response["status"] = "no_questions"
     else:
-        questions: List[JSONType] = []
+        questions: list[JSONType] = []
 
         for insight in insights:
             formatter_cls = QuestionFormatterFactory.get(insight.type)
@@ -1076,7 +1096,7 @@ class HealthResource:
 
 class DumpResource:
     def on_get(self, req: falcon.Request, resp: falcon.Response):
-        keep_types: List[str] = req.get_param_as_list(
+        keep_types: list[str] = req.get_param_as_list(
             "insight_types", required=False, default=[]
         )[:10]
 
@@ -1161,7 +1181,7 @@ class PredictionCollection:
         count: int = req.get_param_as_int("count", min_value=1, default=25)
         barcode: Optional[str] = req.get_param("barcode")
         value_tag: str = req.get_param("value_tag")
-        keep_types: Optional[List[str]] = req.get_param_as_list(
+        keep_types: Optional[list[str]] = req.get_param_as_list(
             "insight_types", required=False
         )
         brands = req.get_param_as_list("brands") or None
@@ -1284,7 +1304,7 @@ class LogoAnnotationCollection:
     def on_get(self, req: falcon.Request, resp: falcon.Response):
         response: JSONType = {}
         barcode: Optional[str] = req.get_param("barcode")
-        keep_types: Optional[List[str]] = req.get_param_as_list("types", required=False)
+        keep_types: Optional[list[str]] = req.get_param_as_list("types", required=False)
         value_tag: str = req.get_param("value_tag")
         page: int = req.get_param_as_int("page", min_value=1, default=1)
         count: int = req.get_param_as_int("count", min_value=1, default=25)
