@@ -2,7 +2,9 @@ import abc
 import datetime
 from dataclasses import dataclass
 from enum import Enum
-from typing import Dict, List, Optional
+from typing import Optional
+
+from requests.exceptions import HTTPError, SSLError, Timeout
 
 from robotoff.insights.dataclass import InsightType
 from robotoff.insights.normalize import normalize_emb_code
@@ -28,7 +30,7 @@ This file allows to annotate products.
 To check whether the annotation already exists or not (and save it and send it to the Open Food Facts database), use the following commands:
     from robotoff.insights.annotate import InsightAnnotatorFactor
     annotator = InsightAnnotatorFactory.get(insight_type)
-    annotator.annotate(insight: ProductInsight, annotation: int, update: bool = True, data: Optional[Dict] = None, auth: Optional[OFFAuthentication] = None, automatic: bool = False)
+    annotator.annotate(insight: ProductInsight, annotation: int, update: bool = True, data: Optional[dict] = None, auth: Optional[OFFAuthentication] = None, automatic: bool = False)
 
 If you don't want to update the Open Food Facts database but only save the insight annotation (if the update is performed on the client side for example), you can call `annotate()` with `update=False`.
 """
@@ -54,6 +56,7 @@ class AnnotationStatus(Enum):
     error_missing_data = 7
     error_invalid_image = 8
     vote_saved = 9
+    error_failed_update = 10
 
 
 SAVED_ANNOTATION_RESULT = AnnotationResult(
@@ -91,6 +94,11 @@ SAVED_ANNOTATION_VOTE_RESULT = AnnotationResult(
     status=AnnotationStatus.vote_saved.name,
     description="the annotation vote was saved",
 )
+FAILED_UPDATE_RESULT = AnnotationResult(
+    status_code=AnnotationStatus.error_failed_update.value,
+    status=AnnotationStatus.error_failed_update.name,
+    description="Open Food Facts update failed",
+)
 
 
 class InsightAnnotator(metaclass=abc.ABCMeta):
@@ -99,19 +107,36 @@ class InsightAnnotator(metaclass=abc.ABCMeta):
         insight: ProductInsight,
         annotation: int,
         update: bool = True,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
         automatic: bool = False,
     ) -> AnnotationResult:
-        with db.atomic():
-            return self._annotate(insight, annotation, update, data, auth, automatic)
+        with db.atomic() as tx:
+            try:
+                return self._annotate(
+                    insight, annotation, update, data, auth, automatic
+                )
+            except HTTPError as e:
+                if e.response.status_code >= 500:
+                    logger.info("HTTPError occurred during OFF update: %s", e)
+                    logger.info("Rolling back SQL transaction")
+                    tx.rollback()
+                    return FAILED_UPDATE_RESULT
+                raise e
+            except (Timeout, SSLError) as e:
+                logger.info(
+                    "Error occurred during OFF update: %s, %s", type(e).__name__, e
+                )
+                logger.info("Rolling back SQL transaction")
+                tx.rollback()
+                return FAILED_UPDATE_RESULT
 
     def _annotate(
         self,
         insight: ProductInsight,
         annotation: int,
         update: bool = True,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
         automatic: bool = False,
     ) -> AnnotationResult:
@@ -154,7 +179,7 @@ class InsightAnnotator(metaclass=abc.ABCMeta):
     def process_annotation(
         self,
         insight: ProductInsight,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
     ) -> AnnotationResult:
         pass
@@ -167,7 +192,7 @@ class PackagerCodeAnnotator(InsightAnnotator):
     def process_annotation(
         self,
         insight: ProductInsight,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
     ) -> AnnotationResult:
         emb_code: str = insight.value
@@ -179,7 +204,7 @@ class PackagerCodeAnnotator(InsightAnnotator):
 
         emb_codes_str: str = product.get("emb_codes", "")
 
-        emb_codes: List[str] = []
+        emb_codes: list[str] = []
         if emb_codes_str:
             emb_codes = emb_codes_str.split(",")
 
@@ -197,7 +222,7 @@ class PackagerCodeAnnotator(InsightAnnotator):
         return UPDATED_ANNOTATION_RESULT
 
     @staticmethod
-    def already_exists(new_emb_code: str, emb_codes: List[str]) -> bool:
+    def already_exists(new_emb_code: str, emb_codes: list[str]) -> bool:
         emb_codes = [normalize_emb_code(emb_code) for emb_code in emb_codes]
 
         normalized_emb_code = normalize_emb_code(new_emb_code)
@@ -212,7 +237,7 @@ class LabelAnnotator(InsightAnnotator):
     def process_annotation(
         self,
         insight: ProductInsight,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
     ) -> AnnotationResult:
         product = get_product(insight.barcode, ["labels_tags"])
@@ -220,7 +245,7 @@ class LabelAnnotator(InsightAnnotator):
         if product is None:
             return MISSING_PRODUCT_RESULT
 
-        labels_tags: List[str] = product.get("labels_tags") or []
+        labels_tags: list[str] = product.get("labels_tags") or []
 
         if insight.value_tag in labels_tags:
             return ALREADY_ANNOTATED_RESULT
@@ -239,7 +264,7 @@ class IngredientSpellcheckAnnotator(InsightAnnotator):
     def process_annotation(
         self,
         insight: ProductInsight,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
     ) -> AnnotationResult:
         barcode = insight.barcode
@@ -280,7 +305,7 @@ class CategoryAnnotator(InsightAnnotator):
     def process_annotation(
         self,
         insight: ProductInsight,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
     ) -> AnnotationResult:
         product = get_product(insight.barcode, ["categories_tags"])
@@ -288,7 +313,7 @@ class CategoryAnnotator(InsightAnnotator):
         if product is None:
             return MISSING_PRODUCT_RESULT
 
-        categories_tags: List[str] = product.get("categories_tags") or []
+        categories_tags: list[str] = product.get("categories_tags") or []
 
         if insight.value_tag in categories_tags:
             return ALREADY_ANNOTATED_RESULT
@@ -308,7 +333,7 @@ class ProductWeightAnnotator(InsightAnnotator):
     def process_annotation(
         self,
         insight: ProductInsight,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
     ) -> AnnotationResult:
         product = get_product(insight.barcode, ["quantity"])
@@ -335,7 +360,7 @@ class ExpirationDateAnnotator(InsightAnnotator):
     def process_annotation(
         self,
         insight: ProductInsight,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
     ) -> AnnotationResult:
         product = get_product(insight.barcode, ["expiration_date"])
@@ -362,7 +387,7 @@ class BrandAnnotator(InsightAnnotator):
     def process_annotation(
         self,
         insight: ProductInsight,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
     ) -> AnnotationResult:
         product = get_product(insight.barcode, ["brands_tags"])
@@ -385,7 +410,7 @@ class StoreAnnotator(InsightAnnotator):
     def process_annotation(
         self,
         insight: ProductInsight,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
     ) -> AnnotationResult:
         product = get_product(insight.barcode, ["stores_tags"])
@@ -393,7 +418,7 @@ class StoreAnnotator(InsightAnnotator):
         if product is None:
             return MISSING_PRODUCT_RESULT
 
-        stores_tags: List[str] = product.get("stores_tags") or []
+        stores_tags: list[str] = product.get("stores_tags") or []
 
         if insight.value_tag in stores_tags:
             return ALREADY_ANNOTATED_RESULT
@@ -412,7 +437,7 @@ class NutritionImageAnnotator(InsightAnnotator):
     def process_annotation(
         self,
         insight: ProductInsight,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
     ) -> AnnotationResult:
         product = get_product(insight.barcode, ["code"])
@@ -444,7 +469,7 @@ class NutritionTableStructureAnnotator(InsightAnnotator):
     def process_annotation(
         self,
         insight: ProductInsight,
-        data: Optional[Dict] = None,
+        data: Optional[dict] = None,
         auth: Optional[OFFAuthentication] = None,
     ) -> AnnotationResult:
         insight.data["annotation"] = data
