@@ -4,19 +4,18 @@ import itertools
 import operator
 import uuid
 from pathlib import Path
-from typing import Any, Dict, Iterable, Iterator, List, Optional, Set, Tuple, Type
+from typing import Any, Iterable, Iterator, Optional, Type
 
-from peewee import fn
 from playhouse.shortcuts import model_to_dict
 
 from robotoff import settings
-from robotoff.brands import BRAND_PREFIX_STORE, in_barcode_range
+from robotoff.brands import get_brand_prefix, in_barcode_range
 from robotoff.insights.dataclass import InsightType
 from robotoff.insights.normalize import normalize_emb_code
 from robotoff.models import Prediction as PredictionModel
 from robotoff.models import ProductInsight, batch_insert
 from robotoff.off import get_server_type
-from robotoff.prediction.types import Prediction, PredictionType
+from robotoff.prediction.types import Prediction
 from robotoff.products import (
     DBProductStore,
     Product,
@@ -24,26 +23,28 @@ from robotoff.products import (
     get_product_store,
     is_valid_image,
 )
+from robotoff.redis import Lock, LockedResourceException
 from robotoff.taxonomy import (
     Taxonomy,
     TaxonomyType,
     get_taxonomy,
     match_taxonomized_value,
 )
+from robotoff.types import PredictionType
 from robotoff.utils import get_logger, text_file_iter
 from robotoff.utils.cache import CachedStore
 
 logger = get_logger(__name__)
 
 
-def load_authorized_labels() -> Set[str]:
+def load_authorized_labels() -> set[str]:
     return set(text_file_iter(settings.OCR_LABEL_WHITELIST_DATA_PATH))
 
 
 AUTHORIZED_LABELS_STORE = CachedStore(load_authorized_labels, expiration_interval=None)
 
 
-def is_selected_image(images: Dict[str, Any], image_id: str) -> bool:
+def is_selected_image(images: dict[str, Any], image_id: str) -> bool:
     """Return True if the image referenced by `image_id` is selected as a
     front, ingredients, nutrition or packaging image in any language.
 
@@ -59,7 +60,7 @@ def is_selected_image(images: Dict[str, Any], image_id: str) -> bool:
 
 
 def is_recent_image(
-    images: Dict[str, Any], image_id: str, max_timedelta: datetime.timedelta
+    images: dict[str, Any], image_id: str, max_timedelta: datetime.timedelta
 ) -> bool:
     """Return True if the image referenced by `image_id` is less than
     `max_timedelta` older than the most recent image, return False otherwise.
@@ -84,15 +85,13 @@ def is_recent_image(
 
     for upload_datetime in remaining_datetimes:
         if upload_datetime - image_datetime > max_timedelta:
-            logger.info(
-                "More recent image: {} > {}".format(upload_datetime, image_datetime)
-            )
+            logger.debug("More recent image: %s > %s", upload_datetime, image_datetime)
             return False
 
     return True
 
 
-def is_valid_insight_image(images: Dict[str, Any], source_image: Optional[str]):
+def is_valid_insight_image(images: dict[str, Any], source_image: Optional[str]):
     """Return True if the source image is valid for insight generation,
     i.e. the image ID is a digit and is referenced in `images`.
 
@@ -110,7 +109,7 @@ def is_valid_insight_image(images: Dict[str, Any], source_image: Optional[str]):
 
 
 def is_trustworthy_insight_image(
-    images: Dict[str, Any],
+    images: dict[str, Any],
     source_image: Optional[str],
     max_timedelta: datetime.timedelta = settings.IMAGE_MAX_TIMEDELTA,
 ):
@@ -142,7 +141,7 @@ def is_trustworthy_insight_image(
 
 def get_existing_insight(
     insight_type: InsightType, barcode: str, server_domain: str
-) -> List[ProductInsight]:
+) -> list[ProductInsight]:
     """Get all insights for specific product and `insight_type`."""
     return list(
         ProductInsight.select().where(
@@ -160,7 +159,7 @@ def is_reserved_barcode(barcode: str) -> bool:
     return barcode.startswith("2")
 
 
-def sort_predictions(predictions: Iterable[Prediction]) -> List[Prediction]:
+def sort_predictions(predictions: Iterable[Prediction]) -> list[Prediction]:
     """Sort predictions by priority, using as keys:
     - priority, specified by data["priority"], prediction with lowest priority
     values (high priority) come first
@@ -186,7 +185,7 @@ def sort_predictions(predictions: Iterable[Prediction]) -> List[Prediction]:
     )
 
 
-def sort_candidates(candidates: Iterable[ProductInsight]) -> List[ProductInsight]:
+def sort_candidates(candidates: Iterable[ProductInsight]) -> list[ProductInsight]:
     """Sort candidates by priority, using as keys:
 
     - priority, specified by data["priority"], candidate with lowest priority
@@ -221,7 +220,7 @@ def sort_candidates(candidates: Iterable[ProductInsight]) -> List[ProductInsight
 
 
 def select_deepest_taxonomized_candidates(
-    candidates: List[Prediction], taxonomy: Taxonomy
+    candidates: list[Prediction], taxonomy: Taxonomy
 ):
     """Filter predictions to only keep the deepest items in the taxonomy.
 
@@ -262,7 +261,7 @@ class InsightImporter(metaclass=abc.ABCMeta):
 
     @staticmethod
     @abc.abstractmethod
-    def get_required_prediction_types() -> Set[PredictionType]:
+    def get_required_prediction_types() -> set[PredictionType]:
         """Return the prediction types that are necessary to generate the
         insight type.
 
@@ -275,7 +274,8 @@ class InsightImporter(metaclass=abc.ABCMeta):
     @classmethod
     def import_insights(
         cls,
-        predictions: List[Prediction],
+        barcode: str,
+        predictions: list[Prediction],
         server_domain: str,
         product_store: DBProductStore,
     ) -> int:
@@ -288,37 +288,48 @@ class InsightImporter(metaclass=abc.ABCMeta):
             if prediction.type not in required_prediction_types:
                 raise ValueError(f"unexpected prediction type: '{prediction.type}'")
 
-        inserts = 0
-        for to_create, to_update, to_delete in cls.generate_insights(
-            predictions, server_domain, product_store
-        ):
-            if to_delete:
-                to_delete_ids = [insight.id for insight in to_delete]
-                logger.info(f"Deleting {len(to_delete_ids)} insights")
-                ProductInsight.delete().where(
-                    ProductInsight.id.in_(to_delete_ids)
-                ).execute()
-            if to_create:
-                inserts += batch_insert(
-                    ProductInsight,
-                    (model_to_dict(insight) for insight in to_create),
-                    50,
+        if (
+            len(
+                prediction_barcodes := set(
+                    prediction.barcode for prediction in predictions
                 )
+            )
+            > 1
+        ):
+            raise ValueError(
+                f"predictions for more than 1 product were provided: {prediction_barcodes}"
+            )
 
-            for insight in to_update:
-                insight.save()
+        inserts = 0
+        to_create, to_update, to_delete = cls.generate_insights(
+            barcode, predictions, server_domain, product_store
+        )
+        if to_delete:
+            to_delete_ids = [insight.id for insight in to_delete]
+            logger.info("Deleting %s insights", len(to_delete_ids))
+            ProductInsight.delete().where(
+                ProductInsight.id.in_(to_delete_ids)
+            ).execute()
+        if to_create:
+            inserts += batch_insert(
+                ProductInsight,
+                (model_to_dict(insight) for insight in to_create),
+                50,
+            )
+
+        for insight in to_update:
+            insight.save()
 
         return inserts
 
     @classmethod
     def generate_insights(
         cls,
-        predictions: List[Prediction],
+        barcode: str,
+        predictions: list[Prediction],
         server_domain: str,
         product_store: DBProductStore,
-    ) -> Iterator[
-        Tuple[List[ProductInsight], List[ProductInsight], List[ProductInsight]]
-    ]:
+    ) -> tuple[list[ProductInsight], list[ProductInsight], list[ProductInsight]]:
         """Given a list of predictions, yield tuples of ProductInsight to
         create, update and delete.
 
@@ -328,72 +339,64 @@ class InsightImporter(metaclass=abc.ABCMeta):
         timestamp = datetime.datetime.utcnow()
         server_type = get_server_type(server_domain).name
 
-        for barcode, group in itertools.groupby(
-            sorted(predictions, key=operator.attrgetter("barcode")),
-            operator.attrgetter("barcode"),
-        ):
-            product = product_store[barcode]
-            references = get_existing_insight(cls.get_type(), barcode, server_domain)
+        product = product_store[barcode]
+        references = get_existing_insight(cls.get_type(), barcode, server_domain)
 
-            if product is None:
-                logger.info(
-                    f"Product {barcode} not found in DB, deleting existing insights"
-                )
-                if references:
-                    yield [], [], references
-                continue
-
-            product_predictions = sort_predictions(group)
-            candidates = [
-                candidate
-                for candidate in cls.generate_candidates(product, product_predictions)
-                if is_valid_insight_image(product.images, candidate.source_image)
-            ]
-            for candidate in candidates:
-                if candidate.automatic_processing is None:
-                    logger.warning(
-                        "Insight with automatic_processing=None: %s", candidate.__data__
-                    )
-                    candidate.automatic_processing = False
-
-                if not is_trustworthy_insight_image(
-                    product.images, candidate.source_image
-                ):
-                    # Don't process automatically if the insight image is not
-                    # trustworthy (too old and not selected)
-                    candidate.automatic_processing = False
-                if candidate.data.get("is_annotation"):
-                    username = candidate.data.get("username")
-                    if username:
-                        # logo annotation by a user
-                        candidate.username = username
-                    # Note: we could add vote annotation for anonymous user,
-                    # but it should be done outside this loop. It's not yet implemented
-
-            to_create, to_update, to_delete = cls.get_insight_update(
-                candidates, references
+        if product is None:
+            logger.info(
+                f"Product {barcode} not found in DB, deleting existing insights"
             )
+            return [], [], references
 
-            for insight in to_create:
-                cls.add_fields(insight, product, timestamp, server_domain, server_type)
+        predictions = sort_predictions(predictions)
+        candidates = [
+            candidate
+            for candidate in cls.generate_candidates(product, predictions)
+            if is_valid_insight_image(product.images, candidate.source_image)
+        ]
+        for candidate in candidates:
+            if candidate.automatic_processing is None:
+                logger.warning(
+                    "Insight with automatic_processing=None: %s", candidate.__data__
+                )
+                candidate.automatic_processing = False
 
-            for insight, reference_insight in to_update:
-                # Keep `reference_insight` in DB (as the value/value_tag/source_image is the same),
-                # but update information from `insight`.
-                # This way, we don't unnecessarily insert/delete rows in ProductInsight table
-                # and we keep associated votes
-                cls.update_fields(insight, reference_insight, product, timestamp)
+            if not is_trustworthy_insight_image(product.images, candidate.source_image):
+                # Don't process automatically if the insight image is not
+                # trustworthy (too old and not selected)
+                candidate.automatic_processing = False
+            if candidate.data.get("is_annotation"):
+                username = candidate.data.get("username")
+                if username:
+                    # logo annotation by a user
+                    candidate.username = username
+                # Note: we could add vote annotation for anonymous user,
+                # but it should be done outside this loop. It's not yet implemented
 
-            yield to_create, [
-                reference_insight for (_, reference_insight) in to_update
-            ], to_delete
+        to_create, to_update, to_delete = cls.get_insight_update(candidates, references)
+
+        for insight in to_create:
+            cls.add_fields(insight, product, timestamp, server_domain, server_type)
+
+        for insight, reference_insight in to_update:
+            # Keep `reference_insight` in DB (as the value/value_tag/source_image is the same),
+            # but update information from `insight`.
+            # This way, we don't unnecessarily insert/delete rows in ProductInsight table
+            # and we keep associated votes
+            cls.update_fields(insight, reference_insight, product, timestamp)
+
+        return (
+            to_create,
+            [reference_insight for (_, reference_insight) in to_update],
+            to_delete,
+        )
 
     @classmethod
     @abc.abstractmethod
     def generate_candidates(
         cls,
         product: Product,
-        predictions: List[Prediction],
+        predictions: list[Prediction],
     ) -> Iterator[ProductInsight]:
         """From a list of Predictions associated with a product, yield
         candidate ProductInsights for import.
@@ -410,11 +413,11 @@ class InsightImporter(metaclass=abc.ABCMeta):
 
     @classmethod
     def get_insight_update(
-        cls, candidates: List[ProductInsight], reference_insights: List[ProductInsight]
-    ) -> Tuple[
-        List[ProductInsight],
-        List[Tuple[ProductInsight, ProductInsight]],
-        List[ProductInsight],
+        cls, candidates: list[ProductInsight], reference_insights: list[ProductInsight]
+    ) -> tuple[
+        list[ProductInsight],
+        list[tuple[ProductInsight, ProductInsight]],
+        list[ProductInsight],
     ]:
         """Return a tuple containing:
         - a list of ProductInsight to create
@@ -426,7 +429,7 @@ class InsightImporter(metaclass=abc.ABCMeta):
         :param candidates: candidate predictions
         :param reference_insights: existing insights of this type and product
         """
-        to_create_or_update: List[Tuple[ProductInsight, Optional[ProductInsight]]] = []
+        to_create_or_update: list[tuple[ProductInsight, Optional[ProductInsight]]] = []
         # Keep already annotated insights in DB
         to_keep_ids = set(
             reference.id
@@ -585,7 +588,7 @@ class PackagerCodeInsightImporter(InsightImporter):
         return InsightType.packager_code
 
     @staticmethod
-    def get_required_prediction_types() -> Set[PredictionType]:
+    def get_required_prediction_types() -> set[PredictionType]:
         return {PredictionType.packager_code}
 
     @classmethod
@@ -608,7 +611,7 @@ class PackagerCodeInsightImporter(InsightImporter):
     def generate_candidates(
         cls,
         product: Product,
-        predictions: List[Prediction],
+        predictions: list[Prediction],
     ) -> Iterator[ProductInsight]:
         yield from (
             ProductInsight(**prediction.to_dict())
@@ -623,7 +626,7 @@ class LabelInsightImporter(InsightImporter):
         return InsightType.label
 
     @staticmethod
-    def get_required_prediction_types() -> Set[PredictionType]:
+    def get_required_prediction_types() -> set[PredictionType]:
         return {PredictionType.label}
 
     @classmethod
@@ -642,7 +645,7 @@ class LabelInsightImporter(InsightImporter):
         )
 
     @classmethod
-    def is_parent_label(cls, tag: str, to_check_labels: Set[str]) -> bool:
+    def is_parent_label(cls, tag: str, to_check_labels: set[str]) -> bool:
         # Check that the predicted label is not a parent of a
         # current/already predicted label
         return get_taxonomy(InsightType.label.name).is_parent_of_any(
@@ -653,7 +656,7 @@ class LabelInsightImporter(InsightImporter):
     def generate_candidates(
         cls,
         product: Product,
-        predictions: List[Prediction],
+        predictions: list[Prediction],
     ) -> Iterator[ProductInsight]:
         candidates = [
             prediction
@@ -687,7 +690,7 @@ class CategoryImporter(InsightImporter):
         return InsightType.category
 
     @staticmethod
-    def get_required_prediction_types() -> Set[PredictionType]:
+    def get_required_prediction_types() -> set[PredictionType]:
         return {PredictionType.category}
 
     @classmethod
@@ -699,7 +702,7 @@ class CategoryImporter(InsightImporter):
         )
 
     @classmethod
-    def is_parent_category(cls, category: str, to_check_categories: Set[str]):
+    def is_parent_category(cls, category: str, to_check_categories: set[str]):
         # Check that the predicted category is not a parent of a
         # current/already predicted category
         return get_taxonomy(InsightType.category.name).is_parent_of_any(
@@ -710,7 +713,7 @@ class CategoryImporter(InsightImporter):
     def generate_candidates(
         cls,
         product: Product,
-        predictions: List[Prediction],
+        predictions: list[Prediction],
     ) -> Iterator[ProductInsight]:
         candidates = [
             prediction
@@ -755,7 +758,7 @@ class ProductWeightImporter(InsightImporter):
         return InsightType.product_weight
 
     @staticmethod
-    def get_required_prediction_types() -> Set[PredictionType]:
+    def get_required_prediction_types() -> set[PredictionType]:
         return {PredictionType.product_weight}
 
     @classmethod
@@ -765,8 +768,8 @@ class ProductWeightImporter(InsightImporter):
         return candidate.value == reference.value
 
     @staticmethod
-    def group_by_subtype(predictions: List[Prediction]) -> Dict[str, List[Prediction]]:
-        predictions_by_subtype: Dict[str, List[Prediction]] = {}
+    def group_by_subtype(predictions: list[Prediction]) -> dict[str, list[Prediction]]:
+        predictions_by_subtype: dict[str, list[Prediction]] = {}
 
         for prediction in predictions:
             matcher_type = prediction.data["matcher_type"]
@@ -779,7 +782,7 @@ class ProductWeightImporter(InsightImporter):
     def generate_candidates(
         cls,
         product: Product,
-        predictions: List[Prediction],
+        predictions: list[Prediction],
     ) -> Iterator[ProductInsight]:
         if product.quantity is not None or not predictions:
             # Don't generate candidates if the product weight is already
@@ -811,7 +814,7 @@ class ExpirationDateImporter(InsightImporter):
         return InsightType.expiration_date
 
     @staticmethod
-    def get_required_prediction_types() -> Set[PredictionType]:
+    def get_required_prediction_types() -> set[PredictionType]:
         return {PredictionType.expiration_date}
 
     @classmethod
@@ -824,7 +827,7 @@ class ExpirationDateImporter(InsightImporter):
     def generate_candidates(
         cls,
         product: Product,
-        predictions: List[Prediction],
+        predictions: list[Prediction],
     ) -> Iterator[ProductInsight]:
         if (product and product.expiration_date) or not predictions:
             return
@@ -845,7 +848,7 @@ class BrandInsightImporter(InsightImporter):
         return InsightType.brand
 
     @staticmethod
-    def get_required_prediction_types() -> Set[PredictionType]:
+    def get_required_prediction_types() -> set[PredictionType]:
         return {PredictionType.brand}
 
     @classmethod
@@ -856,10 +859,10 @@ class BrandInsightImporter(InsightImporter):
 
     @staticmethod
     def is_in_barcode_range(barcode: str, tag: str) -> bool:
-        brand_prefix: Set[Tuple[str, str]] = BRAND_PREFIX_STORE.get()
+        brand_prefix = get_brand_prefix()
 
         if not in_barcode_range(brand_prefix, tag, barcode):
-            logger.info(f"Barcode {barcode} of brand {tag} not in barcode range")
+            logger.info("Barcode %s of brand %s not in barcode range", barcode, tag)
             return False
 
         return True
@@ -868,7 +871,7 @@ class BrandInsightImporter(InsightImporter):
     def generate_candidates(
         cls,
         product: Product,
-        predictions: List[Prediction],
+        predictions: list[Prediction],
     ) -> Iterator[ProductInsight]:
         if product.brands_tags:
             # For now, don't create an insight if a brand has already been provided
@@ -900,7 +903,7 @@ class StoreInsightImporter(InsightImporter):
         return InsightType.store
 
     @staticmethod
-    def get_required_prediction_types() -> Set[PredictionType]:
+    def get_required_prediction_types() -> set[PredictionType]:
         return {PredictionType.store}
 
     @classmethod
@@ -913,7 +916,7 @@ class StoreInsightImporter(InsightImporter):
     def generate_candidates(
         cls,
         product: Product,
-        predictions: List[Prediction],
+        predictions: list[Prediction],
     ) -> Iterator[ProductInsight]:
         for prediction in predictions:
             insight = ProductInsight(**prediction.to_dict())
@@ -935,7 +938,7 @@ def is_valid_product_prediction(
     """
     if not product:
         # the product does not exist (deleted)
-        logger.info(f"Prediction of deleted product {prediction.barcode}")
+        logger.info("Prediction of deleted product %s", prediction.barcode)
         return False
 
     if prediction.source_image and not is_valid_image(
@@ -976,7 +979,8 @@ def import_product_predictions(
     """Import predictions for a specific product.
 
     If a prediction already exists in DB (same (barcode, type, server_domain,
-    source_image, value, value_tag)), it won't be imported.
+    source_image, value, value_tag, predictor, automatic_processing)), it
+    won't be imported.
 
     :param barcode: Barcode of the product. All `product_predictions` must
     have the same barcode.
@@ -992,6 +996,8 @@ def import_product_predictions(
             PredictionModel.source_image,
             PredictionModel.value_tag,
             PredictionModel.value,
+            PredictionModel.predictor,
+            PredictionModel.automatic_processing,
         )
         .where(PredictionModel.barcode == barcode)
         .tuples()
@@ -1009,13 +1015,15 @@ def import_product_predictions(
             prediction.source_image,
             prediction.value_tag,
             prediction.value,
+            prediction.predictor,
+            prediction.automatic_processing,
         )
         not in existing_predictions
     )
     return batch_insert(PredictionModel, to_import, 50)
 
 
-IMPORTERS: List[Type] = [
+IMPORTERS: list[Type] = [
     PackagerCodeInsightImporter,
     LabelInsightImporter,
     CategoryImporter,
@@ -1031,6 +1039,11 @@ def import_insights(
     server_domain: str,
     product_store: Optional[DBProductStore] = None,
 ) -> int:
+    """Import predictions and generate (and import) insights from these
+    predictions.
+
+    :param predictions: an iterable of Predictions to import
+    """
     if product_store is None:
         product_store = get_product_store()
 
@@ -1043,7 +1056,7 @@ def import_insights(
 
 
 def import_insights_for_products(
-    prediction_types_by_barcode: Dict[str, Set[PredictionType]],
+    prediction_types_by_barcode: dict[str, set[PredictionType]],
     server_domain: str,
     product_store: DBProductStore,
 ) -> int:
@@ -1051,12 +1064,15 @@ def import_insights_for_products(
 
     :param prediction_types_by_barcode: a dict that associates each barcode
     with a set of prediction type that were updated
+    :param server_domain: The server domain associated with the predictions
+    :param product_store: The product store to use
+
     :return: Number of imported insights
     """
     imported = 0
     for importer in IMPORTERS:
         required_prediction_types = importer.get_required_prediction_types()
-        selected_barcodes: List[str] = []
+        selected_barcodes: list[str] = []
         for barcode, prediction_types in prediction_types_by_barcode.items():
             if prediction_types >= required_prediction_types:
                 selected_barcodes.append(barcode)
@@ -1068,9 +1084,25 @@ def import_insights_for_products(
                     selected_barcodes, list(required_prediction_types)
                 )
             ]
-            imported += importer.import_insights(
-                predictions, server_domain, product_store
-            )
+
+            for barcode, product_predictions in itertools.groupby(
+                sorted(predictions, key=operator.attrgetter("barcode")),
+                operator.attrgetter("barcode"),
+            ):
+                try:
+                    with Lock(name=f"robotoff:import:{barcode}", expire=60, timeout=10):
+                        imported += importer.import_insights(
+                            barcode,
+                            list(product_predictions),
+                            server_domain,
+                            product_store,
+                        )
+                except LockedResourceException:
+                    logger.info(
+                        "Couldn't acquire insight import lock, skipping insight import for product %s",
+                        barcode,
+                    )
+                    continue
     return imported
 
 
@@ -1078,13 +1110,13 @@ def import_predictions(
     predictions: Iterable[Prediction],
     product_store: DBProductStore,
     server_domain: str,
-) -> Dict[str, Set[PredictionType]]:
+) -> dict[str, set[PredictionType]]:
     """Check validity and import provided Prediction.
 
     :param predictions: the Predictions to import
     :param product_store: The product store to use
     :param server_domain: The server domain associated with the predictions
-    :return: Dict associating each barcode with prediction types that where
+    :return: dict associating each barcode with prediction types that where
     updated in order to re-compute associated insights
     """
     predictions = [
@@ -1094,7 +1126,7 @@ def import_predictions(
     ]
 
     predictions_imported = 0
-    updated_prediction_types_by_barcode: Dict[str, Set[PredictionType]] = {}
+    updated_prediction_types_by_barcode: dict[str, set[PredictionType]] = {}
     for barcode, product_predictions_iter in itertools.groupby(
         sorted(predictions, key=operator.attrgetter("barcode")),
         operator.attrgetter("barcode"),
@@ -1106,7 +1138,7 @@ def import_predictions(
         updated_prediction_types_by_barcode[barcode] = set(
             prediction.type for prediction in product_predictions_group
         )
-    logger.info(f"{predictions_imported} predictions imported")
+    logger.info("%s predictions imported", predictions_imported)
     return updated_prediction_types_by_barcode
 
 
@@ -1141,6 +1173,7 @@ def refresh_insights(
         required_prediction_types = importer.get_required_prediction_types()
         if prediction_types >= required_prediction_types:
             imported += importer.import_insights(
+                barcode,
                 [p for p in predictions if p.type in required_prediction_types],
                 server_domain,
                 product_store,
@@ -1149,29 +1182,9 @@ def refresh_insights(
     return imported
 
 
-def refresh_all_insights(
-    server_domain: str,
-    product_store: Optional[DBProductStore] = None,
-):
-    """Refresh insights of all products for which we have predictions.
-
-    :param server_domain: The server domain associated with the predictions.
-    :param product_store: The product store to use, defaults to None
-    :return: The number of imported insights.
-    """
-    imported = 0
-    for (barcode,) in (
-        PredictionModel.select(fn.Distinct(PredictionModel.barcode)).tuples().iterator()
-    ):
-        logger.info(f"Refreshing insights for product {barcode}")
-        imported += refresh_insights(barcode, server_domain, product_store)
-
-    return imported
-
-
 def get_product_predictions(
-    barcodes: List[str], prediction_types: Optional[List[str]] = None
-) -> Iterator[Dict]:
+    barcodes: list[str], prediction_types: Optional[list[str]] = None
+) -> Iterator[dict]:
     where_clauses = [PredictionModel.barcode.in_(barcodes)]
 
     if prediction_types is not None:
