@@ -1,22 +1,23 @@
 import operator
-from typing import Dict, List, Optional, Set, Tuple
+from typing import Optional
 
+import cachetools
 import numpy as np
 
 from robotoff import settings
 from robotoff.insights.importer import import_insights
 from robotoff.logo_label_type import LogoLabelType
 from robotoff.models import ImageModel, LogoAnnotation, LogoConfidenceThreshold
-from robotoff.prediction.types import Prediction, PredictionType
+from robotoff.prediction.types import Prediction
 from robotoff.slack import NotifierFactory
+from robotoff.types import PredictionType
 from robotoff.utils import get_logger, http_session
-from robotoff.utils.cache import CachedStore
 from robotoff.utils.types import JSONType
 
 logger = get_logger(__name__)
 
 
-LOGO_TYPE_MAPPING: Dict[str, PredictionType] = {
+LOGO_TYPE_MAPPING: dict[str, PredictionType] = {
     "brand": PredictionType.brand,
     "label": PredictionType.label,
 }
@@ -24,7 +25,14 @@ LOGO_TYPE_MAPPING: Dict[str, PredictionType] = {
 UNKNOWN_LABEL: LogoLabelType = ("UNKNOWN", None)
 
 
-BoundingBoxType = Tuple[float, float, float, float]
+BoundingBoxType = tuple[float, float, float, float]
+
+
+def load_resources():
+    """Load and cache resources."""
+    logger.info("Loading logo resources...")
+    get_logo_confidence_thresholds()
+    get_logo_annotations()
 
 
 def compute_iou(box_1: BoundingBoxType, box_2: BoundingBoxType) -> float:
@@ -49,8 +57,8 @@ def compute_iou(box_1: BoundingBoxType, box_2: BoundingBoxType) -> float:
 
 
 def filter_logos(
-    logos: List[JSONType], score_threshold: float, iou_threshold: float = 0.95
-) -> List[Tuple[int, JSONType]]:
+    logos: list[JSONType], score_threshold: float, iou_threshold: float = 0.95
+) -> list[tuple[int, JSONType]]:
     """Select logos that don't intersect with each other
     (IoU < `iou_threshold`) and that have a confidence score above
     `score_threshold`.
@@ -77,7 +85,8 @@ def filter_logos(
     return filtered
 
 
-def get_logo_confidence_thresholds() -> Dict[LogoLabelType, float]:
+@cachetools.cached(cachetools.LRUCache(maxsize=1))
+def get_logo_confidence_thresholds() -> dict[LogoLabelType, float]:
     thresholds = {}
 
     for item in LogoConfidenceThreshold.select().iterator():
@@ -86,12 +95,7 @@ def get_logo_confidence_thresholds() -> Dict[LogoLabelType, float]:
     return thresholds
 
 
-LOGO_CONFIDENCE_THRESHOLDS = CachedStore(
-    get_logo_confidence_thresholds, expiration_interval=10
-)
-
-
-def get_stored_logo_ids() -> Set[int]:
+def get_stored_logo_ids() -> set[int]:
     r = http_session.get(
         settings.BaseURLProvider().robotoff().get() + "/api/v1/ann/stored", timeout=30
     )
@@ -105,7 +109,7 @@ def get_stored_logo_ids() -> Set[int]:
     return set(r.json()["stored"])
 
 
-def add_logos_to_ann(image: ImageModel, logos: List[LogoAnnotation]) -> int:
+def add_logos_to_ann(image: ImageModel, logos: list[LogoAnnotation]) -> int:
     if not logos:
         return 0
 
@@ -121,14 +125,11 @@ def add_logos_to_ann(image: ImageModel, logos: List[LogoAnnotation]) -> int:
         timeout=30,
     )
 
-    if not r.ok:
-        logger.warning(f"error while adding image to ANN ({r.status_code}): %s", r.text)
-        return 0
-
+    r.raise_for_status()
     return r.json()["added"]
 
 
-def save_nearest_neighbors(logos: List[LogoAnnotation]) -> int:
+def save_nearest_neighbors(logos: list[LogoAnnotation]) -> int:
     logo_ids_params = ",".join((str(logo.id) for logo in logos))
     r = http_session.get(
         settings.BaseURLProvider().robotoff().get()
@@ -146,7 +147,7 @@ def save_nearest_neighbors(logos: List[LogoAnnotation]) -> int:
     missing_logo_ids = set(logo_id_to_logo.keys()).difference(set(results.keys()))
 
     if missing_logo_ids:
-        logger.warning("Missing logo IDs in response: %s", missing_logo_ids)
+        logger.info("Missing logo IDs in response: %s", missing_logo_ids)
 
     saved = 0
     for logo_id, logo_results in results.items():
@@ -164,8 +165,9 @@ def save_nearest_neighbors(logos: List[LogoAnnotation]) -> int:
     return saved
 
 
-def get_logo_annotations() -> Dict[int, LogoLabelType]:
-    annotations: Dict[int, LogoLabelType] = {}
+@cachetools.cached(cachetools.LRUCache(maxsize=1))
+def get_logo_annotations() -> dict[int, LogoLabelType]:
+    annotations: dict[int, LogoLabelType] = {}
 
     for logo in (
         LogoAnnotation.select(
@@ -185,9 +187,6 @@ def get_logo_annotations() -> Dict[int, LogoLabelType]:
     return annotations
 
 
-LOGO_ANNOTATIONS_CACHE = CachedStore(get_logo_annotations, expiration_interval=1)
-
-
 def predict_label(logo: LogoAnnotation) -> Optional[LogoLabelType]:
     probs = predict_proba(logo)
 
@@ -199,16 +198,16 @@ def predict_label(logo: LogoAnnotation) -> Optional[LogoLabelType]:
 
 def predict_proba(
     logo: LogoAnnotation, weights: str = "distance"
-) -> Optional[Dict[LogoLabelType, float]]:
+) -> Optional[dict[LogoLabelType, float]]:
     if logo.nearest_neighbors is None:
         return None
 
     nn_distances = logo.nearest_neighbors["distances"]
     nn_logo_ids = logo.nearest_neighbors["logo_ids"]
 
-    logo_annotations = LOGO_ANNOTATIONS_CACHE.get()
+    logo_annotations = get_logo_annotations()
 
-    nn_labels: List[LogoLabelType] = []
+    nn_labels: list[LogoLabelType] = []
     for nn_logo_id in nn_logo_ids:
         nn_labels.append(logo_annotations.get(nn_logo_id, UNKNOWN_LABEL))
 
@@ -216,13 +215,13 @@ def predict_proba(
 
 
 def _predict_proba(
-    logo_ids: List[int],
-    nn_labels: List[LogoLabelType],
-    nn_distances: List[float],
+    logo_ids: list[int],
+    nn_labels: list[LogoLabelType],
+    nn_distances: list[float],
     weights: str,
-) -> Dict[LogoLabelType, float]:
+) -> dict[LogoLabelType, float]:
     weights = get_weights(np.array(nn_distances), weights)
-    labels: List[LogoLabelType] = [UNKNOWN_LABEL] + [
+    labels: list[LogoLabelType] = [UNKNOWN_LABEL] + [
         x for x in set(nn_labels) if x != UNKNOWN_LABEL
     ]
     label_to_id = {label: i for i, label in enumerate(labels)}
@@ -234,7 +233,7 @@ def _predict_proba(
 
     proba_k /= proba_k.sum()
 
-    prediction: Dict[LogoLabelType, float] = {}
+    prediction: dict[LogoLabelType, float] = {}
     for i in range(len(proba_k)):
         prediction[labels[i]] = float(proba_k[i])
 
@@ -276,9 +275,9 @@ def get_weights(dist: np.ndarray, weights: str = "uniform"):
 
 
 def import_logo_insights(
-    logos: List[LogoAnnotation],
+    logos: list[LogoAnnotation],
     server_domain: str,
-    thresholds: Dict[LogoLabelType, float],
+    thresholds: dict[LogoLabelType, float],
     default_threshold: float = 0.1,
 ):
     selected_logos = []
@@ -312,7 +311,7 @@ def import_logo_insights(
 
 
 def generate_insights_from_annotated_logos(
-    logos: List[LogoAnnotation],
+    logos: list[LogoAnnotation],
     server_domain: str,
 ) -> int:
     predictions = []
@@ -334,10 +333,6 @@ def generate_insights_from_annotated_logos(
             continue
 
         image = logo.image_prediction.image
-
-        if prediction.automatic_processing:
-            prediction.data["notify"] = True
-
         prediction.barcode = image.barcode
         prediction.source_image = image.source_image
         predictions.append(prediction)
@@ -345,14 +340,14 @@ def generate_insights_from_annotated_logos(
     imported = import_insights(predictions, server_domain)
 
     if imported:
-        logger.info(f"{imported} logo insights imported after annotation")
+        logger.info("%s logo insights imported after annotation", imported)
     return imported
 
 
 def predict_logo_predictions(
-    logos: List[LogoAnnotation],
-    logo_probs: List[Dict[LogoLabelType, float]],
-) -> List[Prediction]:
+    logos: list[LogoAnnotation],
+    logo_probs: list[dict[LogoLabelType, float]],
+) -> list[Prediction]:
     predictions = []
 
     for logo, probs in zip(logos, logo_probs):
@@ -390,7 +385,7 @@ def predict_logo_predictions(
 def generate_prediction(
     logo_type: str,
     logo_value: Optional[str],
-    data: Dict,
+    data: dict,
     automatic_processing: Optional[bool] = False,
 ) -> Optional[Prediction]:
     """Generate a Prediction from a logo.
