@@ -2,15 +2,16 @@ import datetime
 import itertools
 import operator
 import re
-from typing import Dict, Iterable, List, Optional, Set, Tuple
+from typing import Iterable, Optional
 
 import cachetools
 from flashtext import KeywordProcessor
 
 from robotoff import settings
-from robotoff.prediction.types import Prediction, PredictionType
+from robotoff.prediction.types import Prediction
 from robotoff.products import ProductDataset
 from robotoff.taxonomy import TaxonomyType, get_taxonomy
+from robotoff.types import PredictionType
 from robotoff.utils import dump_json, get_logger, load_json
 from robotoff.utils.text import (
     get_lemmatizing_nlp,
@@ -92,7 +93,18 @@ MATCH_MAPS_EXCEPTIONS = {
     }
 }
 
-MatchMapType = Dict[str, Dict[str, List[Tuple[str, str]]]]
+MatchMapType = dict[str, dict[str, list[tuple[str, str]]]]
+
+
+def load_resources():
+    """Load and cache resources."""
+    logger.info("Loading matcher resources...")
+    get_processors()
+    get_intersect_categories_ingredients()
+
+    for lang in SUPPORTED_LANG:
+        logger.info("Loading NLP for %s...", lang)
+        get_lemmatizing_nlp(lang)
 
 
 def preprocess_product_name(name: str, lang: str) -> str:
@@ -218,12 +230,13 @@ def get_match_maps(taxonomy_type: str) -> MatchMapType:
 
 
 @cachetools.cached(cache=cachetools.TTLCache(maxsize=1, ttl=3600))
-def get_processors() -> Dict[str, KeywordProcessor]:
+def get_processors() -> dict[str, KeywordProcessor]:
     """Return a dict mapping lang to flashtext KeywordProcessor used to
     perform category matching.
 
     This enables a fast matching of query parts against matched maps keys.
     """
+    logger.info("Loading category matcher processors...")
     match_maps = get_match_maps(TaxonomyType.category.name)
     processors = {}
     for lang, items in match_maps.items():
@@ -237,7 +250,7 @@ def get_processors() -> Dict[str, KeywordProcessor]:
     return processors
 
 
-def generate_intersect_categories_ingredients() -> Dict[str, Set[str]]:
+def generate_intersect_categories_ingredients() -> dict[str, set[str]]:
     """Return all taxonomized values that are present both in the ingredient
     and in the category taxonomy.
 
@@ -247,7 +260,7 @@ def generate_intersect_categories_ingredients() -> Dict[str, Set[str]]:
     """
     ingredient_match_maps = get_match_maps(TaxonomyType.ingredient.name)
     category_match_maps = get_match_maps(TaxonomyType.category.name)
-    matches: Dict[str, Set[str]] = {}
+    matches: dict[str, set[str]] = {}
     for lang in SUPPORTED_LANG:
         matches[lang] = set()
 
@@ -267,6 +280,7 @@ def get_intersect_categories_ingredients():
     See `generate_intersect_categories_ingredients` function for more
     information.
     """
+    logger.info("Loading category intersection ingredient...")
     return {
         k: set(v)
         for k, v in load_json(
@@ -275,7 +289,7 @@ def get_intersect_categories_ingredients():
     }
 
 
-def match(query: str, lang: str) -> List[Tuple[str, str, str, str, Tuple[int, int]]]:
+def match(query: str, lang: str) -> list[tuple[str, str, str, str, tuple[int, int]]]:
     """Perform category matching.
 
     If a match is also an ingredient (see
@@ -315,7 +329,7 @@ def match(query: str, lang: str) -> List[Tuple[str, str, str, str, Tuple[int, in
     return filtered
 
 
-def predict_by_lang(product: Dict) -> Dict[str, List[Prediction]]:
+def predict_by_lang(product: dict) -> dict[str, list[Prediction]]:
     """Predict product categories using a matching algorithm on product names
     for all supported languages.
 
@@ -324,7 +338,7 @@ def predict_by_lang(product: Dict) -> Dict[str, List[Prediction]]:
     :return: a dict mapping for each supported lang a list of detected
     category Prediction
     """
-    predictions: Dict[str, List[Prediction]] = {}
+    predictions: dict[str, list[Prediction]] = {}
     for lang in set(product.get("languages_codes", [])) & SUPPORTED_LANG:
         product_name = product.get(f"product_name_{lang}")
 
@@ -363,7 +377,7 @@ def predict_by_lang(product: Dict) -> Dict[str, List[Prediction]]:
     return predictions
 
 
-def predict(product: Dict) -> List[Prediction]:
+def predict(product: dict) -> list[Prediction]:
     """Predict product categories using a matching algorithm on product names.
 
     Flashtext always return the longuest match if several patterns match
