@@ -3,7 +3,7 @@ import datetime
 import logging
 import os
 from pathlib import Path
-from typing import Dict, List, Optional, Tuple
+from typing import Optional
 
 import sentry_sdk
 from sentry_sdk.integrations import Integration
@@ -114,14 +114,12 @@ TAXONOMY_URLS = {
 
 OFF_IMAGE_BASE_URL = BaseURLProvider().static().get() + "/images/products"
 
-OFF_BRANDS_URL = BaseURLProvider().get() + "/brands.json"
-
 _off_password = os.environ.get("OFF_PASSWORD", "")
 _off_user = os.environ.get("OFF_USER", "")
 _off_request_auth = ("off", "off") if _instance_tld() == "net" else None
 
 
-def off_credentials() -> Dict[str, str]:
+def off_credentials() -> dict[str, str]:
     return {"user_id": _off_user, "password": _off_password}
 
 
@@ -170,11 +168,9 @@ POSTGRES_PASSWORD = os.environ.get("POSTGRES_PASSWORD", "postgres")
 
 MONGO_URI = os.environ.get("MONGO_URI", "mongodb://mongodb:27017")
 
-IPC_AUTHKEY = os.environ.get("IPC_AUTHKEY", "IPC").encode("utf-8")
-IPC_HOST = os.environ.get("IPC_HOST", "localhost")
-IPC_PORT = int(os.environ.get("IPC_PORT", 6650))
-IPC_ADDRESS: Tuple[str, int] = (IPC_HOST, IPC_PORT)
-WORKER_COUNT = int(os.environ.get("WORKER_COUNT", 8))
+# Redis
+REDIS_HOST = os.environ.get("REDIS_HOST", "localhost")
+
 # how many seconds should we wait to compute insight on product updated
 UPDATED_PRODUCT_WAIT = float(os.environ.get("ROBOTOFF_UPDATED_PRODUCT_WAIT", 10))
 
@@ -219,7 +215,7 @@ def slack_token() -> str:
 _sentry_dsn = os.environ.get("SENTRY_DSN")
 
 
-def init_sentry(integrations: Optional[List[Integration]] = None):
+def init_sentry(integrations: Optional[list[Integration]] = None):
     if _sentry_dsn:
         integrations = integrations or []
         integrations.append(
@@ -239,7 +235,7 @@ def init_sentry(integrations: Optional[List[Integration]] = None):
 
 OCR_DATA_DIR = DATA_DIR / "ocr"
 OCR_BRANDS_PATH = OCR_DATA_DIR / "brand.txt"
-OCR_TAXONOMY_BRANDS_PATH = OCR_DATA_DIR / "brand_from_taxonomy.txt"
+OCR_TAXONOMY_BRANDS_PATH = OCR_DATA_DIR / "brand_from_taxonomy.gz"
 OCR_LOGO_ANNOTATION_BRANDS_DATA_PATH = OCR_DATA_DIR / "brand_logo_annotation.txt"
 OCR_STORES_DATA_PATH = OCR_DATA_DIR / "store_regex.txt"
 OCR_STORES_NOTIFY_DATA_PATH = OCR_DATA_DIR / "store_notify.txt"
@@ -258,7 +254,7 @@ OCR_TRACE_ALLERGEN_DATA_PATH = OCR_DATA_DIR / "trace_allergen.txt"
 # Try to detect postal codes in France
 OCR_CITIES_FR_PATH = OCR_DATA_DIR / "cities_laposte_hexasmal.json.gz"
 
-BRAND_PREFIX_PATH = DATA_DIR / "brand_prefix.json"
+BRAND_PREFIX_PATH = DATA_DIR / "brand_prefix.json.gz"
 
 # When we're making queries to the API, so that we're not blocked by error
 ROBOTOFF_USER_AGENT = "Robotoff Live Analysis"
@@ -281,12 +277,6 @@ MODELS_DIR = PROJECT_DIR / "models"
 OBJECT_DETECTION_IMAGE_MAX_SIZE = (1024, 1024)
 
 
-OBJECT_DETECTION_MODEL_VERSION = {
-    "nutriscore": "tf-nutriscore-1.0",
-    "nutrition-table": "tf-nutrition-table-1.0",
-    "universal-logo-detector": "tf-universal-logo-detector-1.0",
-}
-
 # We require a minimum of 15 occurences of the brands already on OFF to perform the extraction. This reduces false positive.
 # We require a minimum of 4 characters for the brand
 
