@@ -4,12 +4,14 @@ import os
 import pathlib
 import sys
 from io import BytesIO
-from typing import Any, Callable, Dict, Iterable, List, Optional, Union
+from typing import Any, Callable, Iterable, Optional, Union
 
 import orjson
 import PIL
 import requests
 from PIL import Image
+from requests.adapters import HTTPAdapter
+from requests.exceptions import SSLError, Timeout
 
 from robotoff import settings
 
@@ -48,23 +50,26 @@ def configure_root_logger(logger, level: int = 20):
     handler.setLevel(level)
     logger.addHandler(handler)
 
+    for name in ("redis_lock", "spacy"):
+        logging.getLogger(name).setLevel(logging.WARNING)
+
 
 logger = get_logger(__name__)
 
 
-def jsonl_iter(jsonl_path: Union[str, pathlib.Path]) -> Iterable[Dict]:
+def jsonl_iter(jsonl_path: Union[str, pathlib.Path]) -> Iterable[dict]:
     open_fn = get_open_fn(jsonl_path)
 
     with open_fn(str(jsonl_path), "rt", encoding="utf-8") as f:
         yield from jsonl_iter_fp(f)
 
 
-def gzip_jsonl_iter(jsonl_path: Union[str, pathlib.Path]) -> Iterable[Dict]:
+def gzip_jsonl_iter(jsonl_path: Union[str, pathlib.Path]) -> Iterable[dict]:
     with gzip.open(jsonl_path, "rt", encoding="utf-8") as f:
         yield from jsonl_iter_fp(f)
 
 
-def jsonl_iter_fp(fp) -> Iterable[Dict]:
+def jsonl_iter_fp(fp) -> Iterable[dict]:
     for line in fp:
         line = line.strip("\n")
         if line:
@@ -73,7 +78,7 @@ def jsonl_iter_fp(fp) -> Iterable[Dict]:
 
 def load_json(
     path: Union[str, pathlib.Path], compressed: bool = False
-) -> Union[Dict, List]:
+) -> Union[dict, list]:
     """Load a JSON file.
 
     :param path: the path of the file
@@ -142,7 +147,9 @@ def text_file_iter(
 
 
 def dump_text(filepath: Union[str, pathlib.Path], text_iter: Iterable[str]):
-    with open(str(filepath), "w") as f:
+    open_fn = get_open_fn(filepath)
+
+    with open_fn(str(filepath), "wt") as f:
         for item in text_iter:
             item = item.strip("\n")
             f.write(item + "\n")
@@ -170,16 +177,23 @@ def get_image_from_url(
     :raises ImageLoadingException: _description_
     :return: the Pillow Image or None.
     """
-    if session:
-        r = session.get(image_url)
-    else:
-        r = requests.get(image_url)
+    try:
+        if session:
+            r = session.get(image_url)
+        else:
+            r = requests.get(image_url)
+    except (ConnectionError, SSLError, Timeout) as e:
+        error_message = f"Cannot download image {image_url}: {type(e).__name__}, {e}"
+        if error_raise:
+            raise ImageLoadingException(error_message) from e
+        logger.info(error_message)
+        return None
 
     if not r.ok:
-        error_message = f"Cannot load image {image_url}: HTTP {r.status_code}"
+        error_message = f"Cannot download image {image_url}: HTTP {r.status_code}"
         if error_raise:
             raise ImageLoadingException(error_message)
-        logger.warning(error_message)
+        logger.info(error_message)
         return None
 
     try:
@@ -188,12 +202,12 @@ def get_image_from_url(
         error_message = f"Cannot identify image {image_url}"
         if error_raise:
             raise ImageLoadingException(error_message)
-        logger.warning(error_message)
+        logger.info(error_message)
     except PIL.Image.DecompressionBombError:
         error_message = f"Decompression bomb error for image {image_url}"
         if error_raise:
             raise ImageLoadingException(error_message)
-        logger.warning(error_message)
+        logger.info(error_message)
 
     return None
 
@@ -203,3 +217,6 @@ USER_AGENT_HEADERS = {
     "User-Agent": settings.ROBOTOFF_USER_AGENT,
 }
 http_session.headers.update(USER_AGENT_HEADERS)
+static_adapter = HTTPAdapter(max_retries=3)
+http_session.mount("https://static.openfoodfacts.", static_adapter)
+http_session.mount("https://images.openfoodfacts.", static_adapter)
